@@ -5,12 +5,12 @@ package Bundle::SYP;
 use strict;
 use utf8;
 use warnings 'all';
-our $VERSION = '1.1'; # VERSION
+our $VERSION = '1.2'; # VERSION
 
 1;
 
-
 __END__
+
 =pod
 
 =encoding utf8
@@ -21,12 +21,12 @@ Bundle::SYP - SYP's cozy environment
 
 =head1 VERSION
 
-version 1.1
+version 1.2
 
 =head1 SYNOPSIS
 
  # Debian >= 5.0; Perl >= 5.14
- sudo apt-get install curl gcc git-core libcurl4-gnutls-dev libdb-dev libexpat-dev libncurses-dev libreadline-dev libxml2-dev
+ sudo apt-get install curl gcc git-core libssl-dev libcurl4-gnutls-dev libdb-dev libexpat-dev libncurses-dev libreadline-dev libxml2-dev
 
  perl -MCPAN -e 'install Bundle::SYP'
 
@@ -38,6 +38,8 @@ Term::ANSIColor
 
 Object::ID
 
+Any::Moose
+
 AnyEvent::Net::Curl::Queued
 
 App::Ack
@@ -58,6 +60,8 @@ DBD::SQLite
 
 DBIx::Class
 
+DBIx::Class::Schema::Loader
+
 DB_File
 
 Daemon::Generic
@@ -72,6 +76,8 @@ DateTime::Format::ISO8601
 
 DateTime::Format::Strptime
 
+Devel::Cover
+
 Devel::NYTProf
 
 Devel::REPL
@@ -86,6 +92,8 @@ Digest::SHA1
 
 Dist::Zilla
 
+Dist::Zilla::App::Command::cover
+
 Dist::Zilla::Plugin::CopyFilesFromBuild
 
 Dist::Zilla::Plugin::Git::NextVersion
@@ -120,10 +128,14 @@ Geo::GoogleEarth::Pluggable
 
 HTML::AsText::Fix
 
+HTML::TreeBuilder::LibXML
+
 HTML::Untemplate
 
 HTTP::Tiny
 
+Imager
+
 JSON::Any
 
 JSON::XS
@@ -146,6 +158,8 @@ MongoDB
 
 Moose
 
+Mouse
+
 MooseX::NonMoose
 
 Net::Whois::Raw
@@ -238,4 +252,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
